@@ -3,9 +3,9 @@ use std::{error::Error, fmt};
 /// An error related to parsing of an SPDX license expression
 /// or identifier
 #[derive(Debug, PartialEq)]
-pub struct ParseError<'a> {
+pub struct ParseError {
     /// The string that was attempting to be parsed
-    pub original: &'a str,
+    pub original: String,
     /// The range of characters in the original string that result
     /// in this error
     pub span: std::ops::Range<usize>,
@@ -47,9 +47,9 @@ pub enum Reason {
     GnuNoPlus,
 }
 
-impl<'a> fmt::Display for ParseError<'a> {
+impl fmt::Display for ParseError {
     fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
-        f.write_str(self.original)?;
+        f.write_str(&self.original)?;
         f.write_str("\n")?;
 
         for _ in 0..self.span.start {
@@ -89,10 +89,10 @@ impl fmt::Display for Reason {
                         f.write_fmt(format_args!("{}`{}`", if i > 0 { ", " } else { "" }, exp))?;
                     }
                     f.write_str(" here")
-                } else if !expected.is_empty() {
-                    f.write_fmt(format_args!("expected a `{}` here", expected[0]))
-                } else {
+                } else if expected.is_empty() {
                     f.write_str("the term was not expected here")
+                } else {
+                    f.write_fmt(format_args!("expected a `{}` here", expected[0]))
                 }
             }
             Self::SeparatedPlus => f.write_str("`+` must not follow whitespace"),
@@ -102,7 +102,7 @@ impl fmt::Display for Reason {
     }
 }
 
-impl<'a> Error for ParseError<'a> {
+impl Error for ParseError {
     fn description(&self) -> &str {
         match self.reason {
             Reason::UnknownLicense => "unknown license id",
